package com.xyz.abc.datasource;

import org.infinispan.distribution.group.Group;

public class PnLDataKey implements IDataKey
{
  private static final long serialVersionUID = -4166679841622003708L;

  private final String      legalEntity;
  private final String      transit;
  private final String      book;
  private final String      tradeId;
  private final String      groupId;

  public PnLDataKey(final String legalEntity, final String transit,
      final String book, final String tradeId)
  {
    this.legalEntity = legalEntity;
    this.transit = transit;
    this.book = book;
    this.tradeId = tradeId;
    this.groupId = legalEntity + "|" + transit + "|" + book;
  }

  public String getLegalEntity()
  {
    return legalEntity;
  }

  public String getTransit()
  {
    return transit;
  }

  public String getBook()
  {
    return book;
  }

  public String getTradeId()
  {
    return tradeId;
  }

  @Group
  public String getGroup()
  {
    return groupId;
  }

  @Override
  public String toString()
  {
    return legalEntity + "|" + transit + "|" + book + "|" + tradeId;
  }

  @Override
  public boolean equals(final Object o)
  {
    if (o == this)
    {
      return true;
    }

    if (!(o instanceof PnLDataKey))
    {
      return false;
    }

    final PnLDataKey key = (PnLDataKey) o;
    return comparePotentiallyNullStrings(legalEntity, key.getLegalEntity())
        && comparePotentiallyNullStrings(transit, key.getTransit())
        && comparePotentiallyNullStrings(book, key.getBook())
        && comparePotentiallyNullStrings(tradeId, key.getTradeId());
  }

  @Override
  public int hashCode()
  {
    int hc = 1;
    hc = (hc * 31) + (legalEntity == null ? 0 : legalEntity.hashCode());
    hc = (hc * 31) + (transit == null ? 0 : transit.hashCode());
    hc = (hc * 31) + (book == null ? 0 : book.hashCode());
    hc = (hc * 31) + (tradeId == null ? 0 : tradeId.hashCode());
    return hc;
  }

  private static boolean comparePotentiallyNullStrings(final String s1,
      final String s2)
  {
    if (s1 == null && s2 == null)
    {
      return true;
    }

    if ((s1 == null && s2 != null) || (s1 != null && s2 == null))
    {
      return false;
    }

    return s1.equals(s2);
  }
}
